==> openshift-model-monitoring-6.5.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/SlackActionFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SlackActionFluentImpl<A extends SlackActionFluent<A>> extends BaseFluent<A> implements SlackActionFluent<A>{
  public SlackActionFluentImpl() {
  }
  public SlackActionFluentImpl(SlackAction instance) {
    this.withConfirm(instance.getConfirm()); 
    this.withName(instance.getName()); 
    this.withStyle(instance.getStyle()); 
    this.withText(instance.getText()); 
    this.withType(instance.getType()); 
    this.withUrl(instance.getUrl()); 
    this.withValue(instance.getValue()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private SlackConfirmationFieldBuilder confirm;
  private String name;
  private String style;
  private String text;
  private String type;
  private String url;
  private String value;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildConfirm instead.
   * @return The buildable object.
   */
  @Deprecated
  public SlackConfirmationField getConfirm() {
    return this.confirm!=null ?this.confirm.build():null;
  }
  public SlackConfirmationField buildConfirm() {
    return this.confirm!=null ?this.confirm.build():null;
  }
  public A withConfirm(SlackConfirmationField confirm) {
    _visitables.get("confirm").remove(this.confirm);
    if (confirm!=null){ this.confirm= new SlackConfirmationFieldBuilder(confirm); _visitables.get("confirm").add(this.confirm);} else { this.confirm = null; _visitables.get("confirm").remove(this.confirm); } return (A) this;
  }
  public Boolean hasConfirm() {
    return this.confirm != null;
  }
  public A withNewConfirm(String dismissText,String okText,String text,String title) {
    return (A)withConfirm(new SlackConfirmationField(dismissText, okText, text, title));
  }
  public SlackActionFluent.ConfirmNested<A> withNewConfirm() {
    return new SlackActionFluentImpl.ConfirmNestedImpl();
  }
  public SlackActionFluent.ConfirmNested<A> withNewConfirmLike(SlackConfirmationField item) {
    return new SlackActionFluentImpl.ConfirmNestedImpl(item);
  }
  public SlackActionFluent.ConfirmNested<A> editConfirm() {
    return withNewConfirmLike(getConfirm());
  }
  public SlackActionFluent.ConfirmNested<A> editOrNewConfirm() {
    return withNewConfirmLike(getConfirm() != null ? getConfirm(): new SlackConfirmationFieldBuilder().build());
  }
  public SlackActionFluent.ConfirmNested<A> editOrNewConfirmLike(SlackConfirmationField item) {
    return withNewConfirmLike(getConfirm() != null ? getConfirm(): item);
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getStyle() {
    return this.style;
  }
  public A withStyle(String style) {
    this.style=style; return (A) this;
  }
  public Boolean hasStyle() {
    return this.style != null;
  }
  public String getText() {
    return this.text;
  }
  public A withText(String text) {
    this.text=text; return (A) this;
  }
  public Boolean hasText() {
    return this.text != null;
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public String getUrl() {
    return this.url;
  }
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  public Boolean hasUrl() {
    return this.url != null;
  }
  public String getValue() {
    return this.value;
  }
  public A withValue(String value) {
    this.value=value; return (A) this;
  }
  public Boolean hasValue() {
    return this.value != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SlackActionFluentImpl that = (SlackActionFluentImpl) o;
    if (confirm != null ? !confirm.equals(that.confirm) :that.confirm != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (style != null ? !style.equals(that.style) :that.style != null) return false;
    if (text != null ? !text.equals(that.text) :that.text != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    if (value != null ? !value.equals(that.value) :that.value != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(confirm,  name,  style,  text,  type,  url,  value,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (confirm != null) { sb.append("confirm:"); sb.append(confirm + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (style != null) { sb.append("style:"); sb.append(style + ","); }
    if (text != null) { sb.append("text:"); sb.append(text + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (url != null) { sb.append("url:"); sb.append(url + ","); }
    if (value != null) { sb.append("value:"); sb.append(value + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ConfirmNestedImpl<N> extends SlackConfirmationFieldFluentImpl<SlackActionFluent.ConfirmNested<N>> implements SlackActionFluent.ConfirmNested<N>,Nested<N>{
    ConfirmNestedImpl(SlackConfirmationField item) {
      this.builder = new SlackConfirmationFieldBuilder(this, item);
    }
    ConfirmNestedImpl() {
      this.builder = new SlackConfirmationFieldBuilder(this);
    }
    SlackConfirmationFieldBuilder builder;
    public N and() {
      return (N) SlackActionFluentImpl.this.withConfirm(builder.build());
    }
    public N endConfirm() {
      return and();
    }
    
  }
  
}

==> openshift-model-monitoring-6.7.2-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/SlackActionFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SlackActionFluentImpl<A extends SlackActionFluent<A>> extends BaseFluent<A> implements SlackActionFluent<A>{
  public SlackActionFluentImpl() {
  }
  public SlackActionFluentImpl(SlackAction instance) {
    if (instance != null) {
      this.withConfirm(instance.getConfirm());
      this.withName(instance.getName());
      this.withStyle(instance.getStyle());
      this.withText(instance.getText());
      this.withType(instance.getType());
      this.withUrl(instance.getUrl());
      this.withValue(instance.getValue());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private SlackConfirmationFieldBuilder confirm;
  private String name;
  private String style;
  private String text;
  private String type;
  private String url;
  private String value;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildConfirm instead.
   * @return The buildable object.
   */
  @Deprecated
  public SlackConfirmationField getConfirm() {
    return this.confirm!=null ?this.confirm.build():null;
  }
  public SlackConfirmationField buildConfirm() {
    return this.confirm!=null ?this.confirm.build():null;
  }
  public A withConfirm(SlackConfirmationField confirm) {
    _visitables.get("confirm").remove(this.confirm);
    if (confirm!=null){ this.confirm= new SlackConfirmationFieldBuilder(confirm); _visitables.get("confirm").add(this.confirm);} else { this.confirm = null; _visitables.get("confirm").remove(this.confirm); } return (A) this;
  }
  public Boolean hasConfirm() {
    return this.confirm != null;
  }
  public A withNewConfirm(String dismissText,String okText,String text,String title) {
    return (A)withConfirm(new SlackConfirmationField(dismissText, okText, text, title));
  }
  public SlackActionFluentImpl.ConfirmNested<A> withNewConfirm() {
    return new SlackActionFluentImpl.ConfirmNestedImpl();
  }
  public SlackActionFluentImpl.ConfirmNested<A> withNewConfirmLike(SlackConfirmationField item) {
    return new SlackActionFluentImpl.ConfirmNestedImpl(item);
  }
  public SlackActionFluentImpl.ConfirmNested<A> editConfirm() {
    return withNewConfirmLike(getConfirm());
  }
  public SlackActionFluentImpl.ConfirmNested<A> editOrNewConfirm() {
    return withNewConfirmLike(getConfirm() != null ? getConfirm(): new SlackConfirmationFieldBuilder().build());
  }
  public SlackActionFluentImpl.ConfirmNested<A> editOrNewConfirmLike(SlackConfirmationField item) {
    return withNewConfirmLike(getConfirm() != null ? getConfirm(): item);
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getStyle() {
    return this.style;
  }
  public A withStyle(String style) {
    this.style=style; return (A) this;
  }
  public Boolean hasStyle() {
    return this.style != null;
  }
  public String getText() {
    return this.text;
  }
  public A withText(String text) {
    this.text=text; return (A) this;
  }
  public Boolean hasText() {
    return this.text != null;
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public String getUrl() {
    return this.url;
  }
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  public Boolean hasUrl() {
    return this.url != null;
  }
  public String getValue() {
    return this.value;
  }
  public A withValue(String value) {
    this.value=value; return (A) this;
  }
  public Boolean hasValue() {
    return this.value != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SlackActionFluentImpl that = (SlackActionFluentImpl) o;
    if (!java.util.Objects.equals(confirm, that.confirm)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(style, that.style)) return false;

    if (!java.util.Objects.equals(text, that.text)) return false;

    if (!java.util.Objects.equals(type, that.type)) return false;

    if (!java.util.Objects.equals(url, that.url)) return false;

    if (!java.util.Objects.equals(value, that.value)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(confirm,  name,  style,  text,  type,  url,  value,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (confirm != null) { sb.append("confirm:"); sb.append(confirm + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (style != null) { sb.append("style:"); sb.append(style + ","); }
    if (text != null) { sb.append("text:"); sb.append(text + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (url != null) { sb.append("url:"); sb.append(url + ","); }
    if (value != null) { sb.append("value:"); sb.append(value + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ConfirmNestedImpl<N> extends SlackConfirmationFieldFluentImpl<SlackActionFluentImpl.ConfirmNested<N>> implements SlackActionFluentImpl.ConfirmNested<N>,Nested<N>{
    ConfirmNestedImpl(SlackConfirmationField item) {
      this.builder = new SlackConfirmationFieldBuilder(this, item);
    }
    ConfirmNestedImpl() {
      this.builder = new SlackConfirmationFieldBuilder(this);
    }
    SlackConfirmationFieldBuilder builder;
    public N and() {
      return (N) SlackActionFluentImpl.this.withConfirm(builder.build());
    }
    public N endConfirm() {
      return and();
    }
    
  }
  
}
